# xdist

[![PyPI version](https://badge.fury.io/py/xdist.svg)](https://badge.fury.io/py/xdist)  [![codecov](https://codecov.io/gh/doerlbh/xdist/branch/main/graph/badge.svg?token=)](https://codecov.io/gh/doerlbh/xdist) [![Travis_CI](https://travis-ci.com/doerlbh/xdist.svg?token=&branch=main)](https://travis-ci.com/doerlbh/xdist) [![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

Python library

Created by [Baihan Lin](www.baihan.nyc), Columbia University
